export function getMoment(moment, value, _a) {
    var utc = (_a === void 0 ? {} : _a).utc;
    return utc ? moment.utc(value) : moment(value);
}
export function adapterFactory(moment, options) {
    if (options === void 0) { options = {}; }
    function momentFactory(value) {
        return getMoment(moment, value, options);
    }
    function addDays(date, amount) {
        return momentFactory(date)
            .add(amount, 'days')
            .toDate();
    }
    function addHours(date, amount) {
        return momentFactory(date)
            .add(amount, 'hours')
            .toDate();
    }
    function addMinutes(date, amount) {
        return momentFactory(date)
            .add(amount, 'minutes')
            .toDate();
    }
    function addSeconds(date, amount) {
        return momentFactory(date)
            .add(amount, 'seconds')
            .toDate();
    }
    function differenceInDays(dateLeft, dateRight) {
        return momentFactory(dateLeft).diff(momentFactory(dateRight), 'days');
    }
    function differenceInMinutes(dateLeft, dateRight) {
        return momentFactory(dateLeft).diff(momentFactory(dateRight), 'minutes');
    }
    function differenceInSeconds(dateLeft, dateRight) {
        return momentFactory(dateLeft).diff(momentFactory(dateRight), 'seconds');
    }
    function endOfDay(date) {
        return momentFactory(date)
            .endOf('day')
            .toDate();
    }
    function endOfMonth(date) {
        return momentFactory(date)
            .endOf('month')
            .toDate();
    }
    function endOfWeek(date) {
        return momentFactory(date)
            .endOf('week')
            .toDate();
    }
    function getDay(date) {
        return momentFactory(date).day();
    }
    function isSameDay(dateLeft, dateRight) {
        return momentFactory(dateLeft).isSame(momentFactory(dateRight), 'day');
    }
    function isSameMonth(dateLeft, dateRight) {
        return momentFactory(dateLeft).isSame(momentFactory(dateRight), 'month');
    }
    function isSameSecond(dateLeft, dateRight) {
        return momentFactory(dateLeft).isSame(momentFactory(dateRight), 'second');
    }
    function max() {
        var dates = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            dates[_i] = arguments[_i];
        }
        return moment.max(dates.map(function (date) { return momentFactory(date); })).toDate();
    }
    function setHours(date, hours) {
        return momentFactory(date)
            .hours(hours)
            .toDate();
    }
    function setMinutes(date, minutes) {
        return momentFactory(date)
            .minutes(minutes)
            .toDate();
    }
    function startOfDay(date) {
        return momentFactory(date)
            .startOf('day')
            .toDate();
    }
    function startOfMinute(date) {
        return momentFactory(date)
            .startOf('minute')
            .toDate();
    }
    function startOfMonth(date) {
        return momentFactory(date)
            .startOf('month')
            .toDate();
    }
    function startOfWeek(date) {
        return momentFactory(date)
            .startOf('week')
            .toDate();
    }
    return {
        addDays: addDays,
        addHours: addHours,
        addMinutes: addMinutes,
        addSeconds: addSeconds,
        differenceInDays: differenceInDays,
        differenceInMinutes: differenceInMinutes,
        differenceInSeconds: differenceInSeconds,
        endOfDay: endOfDay,
        endOfMonth: endOfMonth,
        endOfWeek: endOfWeek,
        getDay: getDay,
        isSameDay: isSameDay,
        isSameMonth: isSameMonth,
        isSameSecond: isSameSecond,
        max: max,
        setHours: setHours,
        setMinutes: setMinutes,
        startOfDay: startOfDay,
        startOfMinute: startOfMinute,
        startOfMonth: startOfMonth,
        startOfWeek: startOfWeek
    };
}
//# sourceMappingURL=moment.js.map